==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/compute/kotlin/inputs/BootDiagnosticsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.compute.kotlin.inputs

import com.pulumi.azurenative.compute.inputs.BootDiagnosticsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Boot Diagnostics is a debugging feature which allows you to view Console Output and Screenshot to diagnose VM status. You can easily view the output of your console log. Azure also enables you to see a screenshot of the VM from the hypervisor.
 * @property enabled Whether boot diagnostics should be enabled on the Virtual Machine.
 * @property storageUri Uri of the storage account to use for placing the console output and screenshot. If storageUri is not specified while enabling boot diagnostics, managed storage will be used.
 */
public data class BootDiagnosticsArgs(
    public val enabled: Output<Boolean>? = null,
    public val storageUri: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.compute.inputs.BootDiagnosticsArgs> {
    override fun toJava(): com.pulumi.azurenative.compute.inputs.BootDiagnosticsArgs =
        com.pulumi.azurenative.compute.inputs.BootDiagnosticsArgs.builder()
            .enabled(enabled?.applyValue({ args0 -> args0 }))
            .storageUri(storageUri?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [BootDiagnosticsArgs].
 */
@PulumiTagMarker
public class BootDiagnosticsArgsBuilder internal constructor() {
    private var enabled: Output<Boolean>? = null

    private var storageUri: Output<String>? = null

    /**
     * @param value Whether boot diagnostics should be enabled on the Virtual Machine.
     */
    @JvmName("gahcxkanjlvxpqrw")
    public suspend fun enabled(`value`: Output<Boolean>) {
        this.enabled = value
    }

    /**
     * @param value Uri of the storage account to use for placing the console output and screenshot. If storageUri is not specified while enabling boot diagnostics, managed storage will be used.
     */
    @JvmName("ybqhexldoufaxevl")
    public suspend fun storageUri(`value`: Output<String>) {
        this.storageUri = value
    }

    /**
     * @param value Whether boot diagnostics should be enabled on the Virtual Machine.
     */
    @JvmName("yjtuqrwewkojejif")
    public suspend fun enabled(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.enabled = mapped
    }

    /**
     * @param value Uri of the storage account to use for placing the console output and screenshot. If storageUri is not specified while enabling boot diagnostics, managed storage will be used.
     */
    @JvmName("coglbceueusrwsxu")
    public suspend fun storageUri(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.storageUri = mapped
    }

    internal fun build(): BootDiagnosticsArgs = BootDiagnosticsArgs(
        enabled = enabled,
        storageUri = storageUri,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/compute/kotlin/inputs/BootDiagnosticsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.compute.kotlin.inputs

import com.pulumi.azurenative.compute.inputs.BootDiagnosticsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Boot Diagnostics is a debugging feature which allows you to view Console Output and Screenshot to diagnose VM status. You can easily view the output of your console log. Azure also enables you to see a screenshot of the VM from the hypervisor.
 * @property enabled Whether boot diagnostics should be enabled on the Virtual Machine.
 * @property storageUri Uri of the storage account to use for placing the console output and screenshot. If storageUri is not specified while enabling boot diagnostics, managed storage will be used.
 */
public data class BootDiagnosticsArgs(
    public val enabled: Output<Boolean>? = null,
    public val storageUri: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.compute.inputs.BootDiagnosticsArgs> {
    override fun toJava(): com.pulumi.azurenative.compute.inputs.BootDiagnosticsArgs =
        com.pulumi.azurenative.compute.inputs.BootDiagnosticsArgs.builder()
            .enabled(enabled?.applyValue({ args0 -> args0 }))
            .storageUri(storageUri?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [BootDiagnosticsArgs].
 */
@PulumiTagMarker
public class BootDiagnosticsArgsBuilder internal constructor() {
    private var enabled: Output<Boolean>? = null

    private var storageUri: Output<String>? = null

    /**
     * @param value Whether boot diagnostics should be enabled on the Virtual Machine.
     */
    @JvmName("oikfmsclymicgahi")
    public suspend fun enabled(`value`: Output<Boolean>) {
        this.enabled = value
    }

    /**
     * @param value Uri of the storage account to use for placing the console output and screenshot. If storageUri is not specified while enabling boot diagnostics, managed storage will be used.
     */
    @JvmName("dmncaislnilwxuva")
    public suspend fun storageUri(`value`: Output<String>) {
        this.storageUri = value
    }

    /**
     * @param value Whether boot diagnostics should be enabled on the Virtual Machine.
     */
    @JvmName("mdclrrncuxhoyfjb")
    public suspend fun enabled(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.enabled = mapped
    }

    /**
     * @param value Uri of the storage account to use for placing the console output and screenshot. If storageUri is not specified while enabling boot diagnostics, managed storage will be used.
     */
    @JvmName("dkxcleyqxhftrvoo")
    public suspend fun storageUri(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.storageUri = mapped
    }

    internal fun build(): BootDiagnosticsArgs = BootDiagnosticsArgs(
        enabled = enabled,
        storageUri = storageUri,
    )
}
